.. _modules-graph_inspector:

#################
 Graph Inspector
#################

This module is used to inspect graphs. This inspection includes:

-  Distribution plots of node & edge attributes.
-  Interactive plot of each subgraph.
-  Interactive plot of isolated nodes.
-  Description of the graph in the console.

.. automodule:: anemoi.graphs.inspector
   :members:
   :no-undoc-members:
   :show-inheritance:
